@@ -1,4 +1,4 @@
-cat("\ntest Nugget")
+cat("\ntest Nugget:")
 
 data(Loaloa)
 ## use 1st 30 obs as this is slow:
@@ -8,4 +8,4 @@ loafit <- corrHLfit(cbind(npos,ntot-npos)~elev1+elev2+elev3+elev4+maxNDVI1+seNDV
           init.corrHLfit=list(Nugget=0.1),ranFix=list(nu=0.5)) 
 
 expect_equal(attr(loafit$corrPars,"type"),list(nu="fix",Nugget="outer",rho="outer"))
-expect_equal(loafit$corrPars$Nugget,0.04578246,tolerance=1e-5) ## NB flat p_bv for Nugget
+expect_equal(loafit$corrPars$Nugget,0.04578246,tolerance=2e-5) ## NB flat p_bv for Nugget
